==> socratadata_0.1.0.tar.gz: socratadata/tests/testthat/soc_query/soda.demo.socrata.com/resource/4tka-6guv.json-668050.R <==
structure(list(method = "GET", url = "https://soda.demo.socrata.com/resource/4tka-6guv.json?%24select=magnitude%2C%20count%28%2A%29%20as%20count&%24where=magnitude%20%3E%206&%24group=magnitude&%24limit=10000", 
    status_code = 200L, headers = structure(list(Server = "nginx", 
        Date = "Tue, 22 Jul 2025 20:42:04 GMT", `Content-Type` = "application/json;charset=utf-8", 
        `Transfer-Encoding` = "chunked", Connection = "keep-alive", 
        `Access-Control-Allow-Origin` = "*", ETag = "\"Zm94dHJvdC4zMzQxMl80XzEyMmZteG1pelJmNzRrYVBFRHJjMGx3NTN4XzIxNA-aCMNYSK4O-mBYZH7LPgGE4wrqgY--gzip--gzip\"", 
        `X-SODA2-Fields` = "[\"magnitude\",\"count\"]", `X-SODA2-Types` = "[\"number\",\"number\"]", 
        `X-SODA2-Data-Out-Of-Date` = "false", `X-SODA2-Truth-Last-Modified` = "Wed, 04 Sep 2019 17:25:46 GMT", 
        `X-SODA2-Secondary-Last-Modified` = "Wed, 04 Sep 2019 17:25:46 GMT", 
        `Last-Modified` = "Wed, 04 Sep 2019 17:25:46 GMT", Vary = "Accept-Encoding", 
        `Content-Encoding` = "gzip", Age = "0", `X-Socrata-Region` = "aws-us-east-1-fedramp-prod", 
        `Strict-Transport-Security` = "max-age=31536000; includeSubDomains", 
        `X-Socrata-RequestId` = "2a3b5e6ad0c10ed60e3ef31025d12965"), class = "httr2_headers"), 
    body = charToRaw("[{\"magnitude\":\"6.1\",\"count\":\"6\"}\n,{\"magnitude\":\"6.2\",\"count\":\"4\"}\n,{\"magnitude\":\"6.4\",\"count\":\"1\"}\n,{\"magnitude\":\"6.5\",\"count\":\"2\"}\n,{\"magnitude\":\"6.6\",\"count\":\"4\"}]\n"), 
    timing = c(redirect = 0, namelookup = 1.3e-05, connect = 0, 
    pretransfer = 6.7e-05, starttransfer = 0.180889, total = 0.180973
    ), cache = new.env(parent = emptyenv())), class = "httr2_response")

==> socratadata_0.1.1.tar.gz: socratadata/tests/testthat/soc_query/soda.demo.socrata.com/resource/4tka-6guv.json-668050.R <==
structure(list(method = "GET", url = "https://soda.demo.socrata.com/resource/4tka-6guv.json?%24select=magnitude%2C%20count%28%2A%29%20as%20count&%24where=magnitude%20%3E%206&%24group=magnitude&%24limit=10000", 
    status_code = 200L, headers = structure(list(Server = "nginx", 
        Date = "Mon, 18 Aug 2025 16:31:04 GMT", `Content-Type` = "application/json;charset=utf-8", 
        `Transfer-Encoding` = "chunked", Connection = "keep-alive", 
        `Access-Control-Allow-Origin` = "*", ETag = "\"Zm94dHJvdC4zMzQxMl80XzEyMmZteG1pelJmNzRrYVBFRHJjMGx3NTN4XzIxNA-aCMNYSK4O-mBYZH7LPgGE4wrqgY--gzip--gzip\"", 
        `X-SODA2-Fields` = "[\"magnitude\",\"count\"]", `X-SODA2-Types` = "[\"number\",\"number\"]", 
        `X-SODA2-Data-Out-Of-Date` = "false", `X-SODA2-Truth-Last-Modified` = "Wed, 04 Sep 2019 17:25:46 GMT", 
        `X-SODA2-Secondary-Last-Modified` = "Wed, 04 Sep 2019 17:25:46 GMT", 
        `Last-Modified` = "Wed, 04 Sep 2019 17:25:46 GMT", Vary = "Accept-Encoding", 
        `Content-Encoding` = "gzip", Age = "0", `X-Socrata-Region` = "aws-us-east-1-fedramp-prod", 
        `Strict-Transport-Security` = "max-age=31536000; includeSubDomains", 
        `X-Socrata-RequestId` = "3bee3cea10823a8505812f432c2d8a08"), class = "httr2_headers"), 
    body = charToRaw("[{\"magnitude\":\"6.1\",\"count\":\"6\"}\n,{\"magnitude\":\"6.2\",\"count\":\"4\"}\n,{\"magnitude\":\"6.4\",\"count\":\"1\"}\n,{\"magnitude\":\"6.5\",\"count\":\"2\"}\n,{\"magnitude\":\"6.6\",\"count\":\"4\"}]\n"), 
    timing = c(redirect = 0, namelookup = 1.3e-05, connect = 0, 
    pretransfer = 7.2e-05, starttransfer = 0.153623, total = 0.153731
    ), cache = new.env(parent = emptyenv())), class = "httr2_response")
